# Simple Torch
`implement by numpy`


## autograd
###  tensor
Realize the function of basic operations between tensors,also,recording dependencies between tensors and the grad of tensors.
### function
Realize the function of activation function
### parameter
Quickly create random tensors with requires_grad=True.
### module
Realize the function of recording parameters
###  optim
Achieve optimization of the model
## tests
Test for autograd function<br>

`Games to test performance`  
fizz_buzz<br>
simple_learned_function<br>
minimize_a_function<br>



   

